@@ -1,7 +1,7 @@
 import rdflib, sys
 from rdflib.Graph import Graph
 from rdflib.Collection import Collection
-from n3 import parse, AHT
+from n3 import parse, Tags
 
 swapImplies = rdflib.URIRef('http://www.w3.org/2000/10/swap/log#implies')
 owlSameAs = rdflib.URIRef('http://www.w3.org/2002/07/owl#sameAs')
@@ -16,10 +16,10 @@ class GraphParser:
     
     def processGraph(self):
         for s in self.statements:
-            if type(s) is AHT.SimpleStatement: self.addPropertiesToNode(self.processPath(s[0]), s[1])
-            elif type(s) is AHT.Existential: pass
-            elif type(s) is AHT.Universal: pass
-            elif type(s) is AHT.PrefixDeclaration: self.prefixes[s[0]] = s[1]
+            if s in Tags.SimpleStatement: self.addPropertiesToNode(self.processPath(s[0]), s[1])
+            elif s in Tags.Existential: pass
+            elif s in Tags.Universal: pass
+            elif s in Tags.PrefixDeclaration: self.prefixes[s[0]] = s[1]
         return self.graph
     
     def processPath(self, p):
@@ -32,33 +32,33 @@ class GraphParser:
         return node
     
     def processNode(self, n):
-        if type(n) is AHT.Literal: return rdflib.Literal(n[0])
+        if n in Tags.Literal: return rdflib.Literal(n[0])
         elif type(n) in (int, float, long): return rdflib.Literal(n)
-        elif type(n) is AHT.URI: return rdflib.URIRef(n)
-        elif type(n) is AHT.Qname and n[0] == '_:':
+        elif n in Tags.URI: return rdflib.URIRef(n)
+        elif n in Tags.Qname and n[0] == '_:':
             if n[1] not in self.bnodes: self.bnodes[n[1]] = rdflib.BNode()
             return self.bnodes[n[1]]
-        elif type(n) is AHT.Qname: return rdflib.URIRef(self.prefixes[n[0] or ':'] + n[1])
-        elif type(n) is AHT.Variable: return rdflib.Variable(n)
-        elif type(n) is AHT.ThisNode: return self.graph
-        elif type(n) is AHT.PathListNode:
+        elif n in Tags.Qname: return rdflib.URIRef(self.prefixes[n[0] or ':'] + n[1])
+        elif n in Tags.Variable: return rdflib.Variable(n)
+        elif n in Tags.ThisNode: return self.graph
+        elif n in Tags.PathListNode:
             b = rdflib.BNode()
             Collection(self.graph, b, map(self.processPath, n))
             return b
-        elif type(n) is AHT.PropertyListNode:
+        elif n in Tags.PropertyListNode:
             b = rdflib.BNode()
             self.addPropertiesToNode(b, n)
             return b
-        elif type(n) is AHT.Formula:
+        elif n in Tags.Formula:
             g = GraphParser(n, self.prefixes)
             return g.processGraph()
         
     def processVerb(self, v):
-        active = type(v) in (AHT.Implies, AHT.SameAs, AHT.IsA, AHT.Path)
-        if type(v) in (AHT.ImpliedBy, AHT.Implies): return swapImplies, active
-        elif type(v) is AHT.SameAs: return owlSameAs, active #the funny joke is that sameAs is more like a copula, which is not really active nor passive lolololol
-        elif type(v) is AHT.IsA: return rdfsType, active
-        elif type(v) in (AHT.Path, AHT.PassiveVerb): return self.processPath(v), active
+        active = v in Tags.Implies or v in Tags.SameAs or v in Tags.IsA or v in Tags.Path
+        if v in Tags.ImpliedBy or v in Tags.Implies: return swapImplies, active
+        elif v in Tags.SameAs: return owlSameAs, active #the funny joke is that sameAs is more like a copula, which is not really active nor passive lolololol
+        elif v in Tags.IsA: return rdfsType, active
+        elif v in Tags.Path or v in Tags.PassiveVerb: return self.processPath(v), active
         
     def addPropertiesToNode(self, node, propertyList):
         for verb, objects in propertyList:
@@ -70,4 +70,5 @@ class GraphParser:
 
 if __name__ == '__main__':
     g = GraphParser(parse(sys.stdin.read())).processGraph()
-    print g.serialize()
\ No newline at end of file
+    print g.serialize()
+    #print '\n'.join(str(t) for t in g.triples((None, None, None)))
\ No newline at end of file
